==> mariadb-connector-odbc_3.1.4.orig.tar.gz: mariadb-connector-odbc-3.1.4-ga-src/dsn/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g e n e r a t e d   i n c l u d e   f i l e . 
 
 / /   U s e d   b y   o d b c _ d s n . r c 
 
 / / 
 
 # d e f i n e   P B _ N E X T                                                   3 
 
 # d e f i n e   I D C A N C E L 3                                               4 
 
 # d e f i n e   P B _ P R E V                                                   5 
 
 # d e f i n e   I D C A N C E L 4                                               6 
 
 # d e f i n e   I D D _ D I A L O G 1                                           1 0 1 
 
 # d e f i n e   T a b _ D S N                                                   1 0 2 
 
 # d e f i n e   P a g e _ 0                                                     1 0 3 
 
 # d e f i n e   T a b _ C u r s o r                                             1 0 4 
 
 # d e f i n e   I D B _ B I T M A P 1                                           1 0 5 
 
 # d e f i n e   T a b _ M e t a d a t a                                         1 0 6 
 
 # d e f i n e   T a b _ C o n n e c t i o n                                     1 0 8 
 
 # d e f i n e   T a b _ C o n n e c t                                           1 0 9 
 
 # d e f i n e   P a g e _ 1                                                     1 1 0 
 
 # d e f i n e   P a g e _ 2                                                     1 1 1 
 
 # d e f i n e   P a g e _ 3                                                     1 1 2 
 
 # d e f i n e   P a g e _ 4                                                     1 1 4 
 
 # d e f i n e   P a g e _ 5                                                     1 1 5 
 
 # d e f i n e   D S N _ N a m e                                                 1 0 0 2 
 
 # d e f i n e   D S N _ D e s c r i p t i o n                                   1 0 0 3 
 
 # d e f i n e   D S N _ D a t a b a s e                                         1 0 0 5 
 
 # d e f i n e   D S N _ U s e r N a m e                                         1 0 1 3 
 
 # d e f i n e   D S N _ P a s s w o r d                                         1 0 1 4 
 
 # d e f i n e   D S N _ T e s t                                                 1 0 1 5 
 
 # d e f i n e   I D C _ C H E C K 2                                             1 0 1 7 
 
 # d e f i n e   r b T C P                                                       1 0 1 8 
 
 # d e f i n e   I D C _ C H E C K 3                                             1 0 1 9 
 
 # d e f i n e   r b P i p e                                                     1 0 2 0 
 
 # d e f i n e   I D C _ C H E C K 4                                             1 0 2 1 
 
 # d e f i n e   t x t S e r v e r N a m e                                       1 0 2 2 
 
 # d e f i n e   I D C _ C H E C K 5                                             1 0 2 3 
 
 # d e f i n e   l b l S e r v e r N a m e                                       1 0 2 4 
 
 # d e f i n e   t x t P o r t                                                   1 0 2 6 
 
 # d e f i n e   l b l P o r t                                                   1 0 2 8 
 
 # d e f i n e   I D C _ C H E C K 8                                             1 0 2 9 
 
 # d e f i n e   I D C _ C H E C K 9                                             1 0 3 0 
 
 # d e f i n e   t x t S e r v e r                                               1 0 3 1 
 
 # d e f i n e   t x t U s e r N a m e                                           1 0 3 2 
 
 # d e f i n e   I D C _ E D I T 4                                               1 0 3 3 
 
 # d e f i n e   t x t P a s s w o r d                                           1 0 3 4 
 
 # d e f i n e   p b T e s t D S N                                               1 0 3 5 
 
 # d e f i n e   I D C _ C O M B O 1                                             1 0 3 6 
 
 # d e f i n e   c b D a t a b a s e                                             1 0 3 7 
 
 # d e f i n e   t x t I n i t C m d                                             1 0 3 8 
 
 # d e f i n e   c k R e c o n n e c t                                           1 0 3 9 
 
 # d e f i n e   c b C h a r s e t                                               1 0 4 0 
 
 # d e f i n e   c k C o n n e c t P r o m p t                                   1 0 4 1 
 
 # d e f i n e   I D C _ E D I T 1                                               1 0 4 2 
 
 # d e f i n e   t x t C o n n e c t i o n T i m e O u t                         1 0 4 3 
 
 # d e f i n e   t x t D r i v e r                                               1 2 0 0 
 
 # d e f i n e   c k E n a b l e D C                                             1 0 4 5 
 
 # d e f i n e   c k R e c o n n e c t 2                                         1 0 4 6 
 
 # d e f i n e   c k D i s a b l e D r i v e r C u r s o r S u p p o r t         1 0 4 7 
 
 # d e f i n e   c k N o C a c h e F o r w a r d O n l y                         1 0 4 8 
 
 # d e f i n e   c k P r e f e t c h                                             1 0 4 9 
 
 # d e f i n e   I c k U s e I S                                                 1 0 5 0 
 
 # d e f i n e   c k U s e I S                                                   1 0 5 1 
 
 # d e f i n e   c k I g n o r e S c h e m a                                     1 0 5 2 
 
 # d e f i n e   t x t D s n N a m e                                             1 0 5 3 
 
 # d e f i n e   t x t D S N D e s c r i p t i o n                               1 0 5 4 
 
 # d e f i n e   c k E n a b l e D y n a m i c C u r s o r                       1 1 0 0 
 
 # d e f i n e   c k D i s a b l e D r i v e r C u r s o r                       1 1 0 1 
 
 # d e f i n e   c k D o n t C a c h e F o r w a r d C u r s o r                 1 1 0 2 
 
 # d e f i n e   c k F o r w a r d C u r s o r O n l y                           1 1 0 3 
 
 # d e f i n e   c k R e t u r n M a t c h e d R o w s                           1 1 0 4 
 
 # d e f i n e   c k E n a b l e S Q L A u t o I s N u l l                       1 1 0 5 
 
 # d e f i n e   c k P a d C h a r F u l l L e n g t h                           1 1 0 6 
 
 # d e f i n e   c k N u l l D a t e                                             1 1 0 7 
 
 # d e f i n e   c k P r e f e t c h R o w s                                     1 1 0 8 
 
 # d e f i n e   c k C o m p r e s s e d                                         1 1 0 9 
 
 # d e f i n e   c k D e b u g                                                   1 1 1 0 
 
 # d e f i n e   c k P r e f e t c h R o w s 2                                   1 1 1 1 
 
 # d e f i n e   c k I g n o r e S p a c e                                       1 1 1 2 
 
 # d e f i n e   c k M u l t i S t m t                                           1 1 1 3 
 
 # d e f i n e   c k M a t c h e d R o w s                                       1 1 1 4 
 
 # d e f i n e   t x t P l u g i n D i r                                         1 1 1 5 
 
 # d e f i n e   p b P l u g i n d i r B r o w s e                               1 1 1 6 
 
 # d e f i n e   t x t S s l K e y                                               1 1 1 7 
 
 # d e f i n e   t x t S s l C e r t                                             1 1 1 8 
 
 # d e f i n e   t x t S s l C e r t A u t h                                     1 1 1 9 
 
 # d e f i n e   t x t S s l C a P a t h                                         1 1 2 0 
 
 # d e f i n e   t x t S s l C i p h e r                                         1 1 2 1 
 
 # d e f i n e   c b S s l V e r i f y                                           1 1 2 2 
 
 # d e f i n e   p b C a P a t h B r o w s e                                     1 1 2 3 
 
 # d e f i n e   p b K e y B r o w s e                                           1 1 2 4 
 
 # d e f i n e   p b C e r t B r o w s e                                         1 1 2 5 
 
 # d e f i n e   p b C a C e r t B r o w s e                                     1 1 2 6 
 
 # d e f i n e   c k U s e M y c n f                                             1 1 2 7 
 
 / *   T L S V E R S I O N   c h e c k b o x   g r o u p .   I d   d e t e r m i n e s   b i t   * / 
 
 # d e f i n e   c b T l s 1 1                                                   1 1 2 8 
 
 # d e f i n e   c b T l s 1 2                                                   1 1 2 9 
 
 # d e f i n e   c b T l s 1 3                                                   1 1 3 1 
 
 / *   E n d   o f   T L S V E R S I O N   * / 
 
 # d e f i n e   c b F o r c e T l s                                             1 3 0 0 
 
 # d e f i n e   t x t S e r v e r K e y                                         1 2 0 0 
 
 # d e f i n e   p b S e r v e r K e y B r o w s e                               1 2 0 1 
 
 # d e f i n e   t x t T l s P e e r F p                                         1 2 1 0 
 
 # d e f i n e   t x t T l s P e e r F p L i s t                                 1 2 1 1 
 
 # d e f i n e   p b F p L i s t B r o w s e                                     1 2 1 2 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 0 7 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   4 0 0 0 1 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 4 4 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 1 3 
 
 # e n d i f 
 
 # e n d i f 
 
 

==> mariadb-connector-odbc_3.1.9.orig.tar.gz: mariadb-connector-odbc-3.1.9-ga-src/dsn/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g e n e r a t e d   i n c l u d e   f i l e . 
 
 / /   U s e d   b y   o d b c _ d s n . r c 
 
 / / 
 
 # d e f i n e   P B _ N E X T                                                   3 
 
 # d e f i n e   I D C A N C E L 3                                               4 
 
 # d e f i n e   P B _ P R E V                                                   5 
 
 # d e f i n e   I D C A N C E L 4                                               6 
 
 # d e f i n e   I D D _ D I A L O G 1                                           1 0 1 
 
 # d e f i n e   T a b _ D S N                                                   1 0 2 
 
 # d e f i n e   P a g e _ 0                                                     1 0 3 
 
 # d e f i n e   T a b _ C u r s o r                                             1 0 4 
 
 # d e f i n e   I D B _ B I T M A P 1                                           1 0 5 
 
 # d e f i n e   T a b _ M e t a d a t a                                         1 0 6 
 
 # d e f i n e   T a b _ C o n n e c t i o n                                     1 0 8 
 
 # d e f i n e   T a b _ C o n n e c t                                           1 0 9 
 
 # d e f i n e   P a g e _ 1                                                     1 1 0 
 
 # d e f i n e   P a g e _ 2                                                     1 1 1 
 
 # d e f i n e   P a g e _ 3                                                     1 1 2 
 
 # d e f i n e   P a g e _ 4                                                     1 1 4 
 
 # d e f i n e   P a g e _ 5                                                     1 1 5 
 
 # d e f i n e   D S N _ N a m e                                                 1 0 0 2 
 
 # d e f i n e   D S N _ D e s c r i p t i o n                                   1 0 0 3 
 
 # d e f i n e   D S N _ D a t a b a s e                                         1 0 0 5 
 
 # d e f i n e   D S N _ U s e r N a m e                                         1 0 1 3 
 
 # d e f i n e   D S N _ P a s s w o r d                                         1 0 1 4 
 
 # d e f i n e   D S N _ T e s t                                                 1 0 1 5 
 
 # d e f i n e   I D C _ C H E C K 2                                             1 0 1 7 
 
 # d e f i n e   r b T C P                                                       1 0 1 8 
 
 # d e f i n e   I D C _ C H E C K 3                                             1 0 1 9 
 
 # d e f i n e   r b P i p e                                                     1 0 2 0 
 
 # d e f i n e   I D C _ C H E C K 4                                             1 0 2 1 
 
 # d e f i n e   t x t S e r v e r N a m e                                       1 0 2 2 
 
 # d e f i n e   I D C _ C H E C K 5                                             1 0 2 3 
 
 # d e f i n e   l b l S e r v e r N a m e                                       1 0 2 4 
 
 # d e f i n e   t x t P o r t                                                   1 0 2 6 
 
 # d e f i n e   l b l P o r t                                                   1 0 2 8 
 
 # d e f i n e   I D C _ C H E C K 8                                             1 0 2 9 
 
 # d e f i n e   I D C _ C H E C K 9                                             1 0 3 0 
 
 # d e f i n e   t x t S e r v e r                                               1 0 3 1 
 
 # d e f i n e   t x t U s e r N a m e                                           1 0 3 2 
 
 # d e f i n e   I D C _ E D I T 4                                               1 0 3 3 
 
 # d e f i n e   t x t P a s s w o r d                                           1 0 3 4 
 
 # d e f i n e   p b T e s t D S N                                               1 0 3 5 
 
 # d e f i n e   I D C _ C O M B O 1                                             1 0 3 6 
 
 # d e f i n e   c b D a t a b a s e                                             1 0 3 7 
 
 # d e f i n e   t x t I n i t C m d                                             1 0 3 8 
 
 # d e f i n e   c k R e c o n n e c t                                           1 0 3 9 
 
 # d e f i n e   c b C h a r s e t                                               1 0 4 0 
 
 # d e f i n e   c k C o n n e c t P r o m p t                                   1 0 4 1 
 
 # d e f i n e   I D C _ E D I T 1                                               1 0 4 2 
 
 # d e f i n e   t x t C o n n e c t i o n T i m e O u t                         1 0 4 3 
 
 # d e f i n e   t x t D r i v e r                                               1 2 0 0 
 
 # d e f i n e   c k E n a b l e D C                                             1 0 4 5 
 
 # d e f i n e   c k R e c o n n e c t 2                                         1 0 4 6 
 
 # d e f i n e   c k D i s a b l e D r i v e r C u r s o r S u p p o r t         1 0 4 7 
 
 # d e f i n e   c k N o C a c h e F o r w a r d O n l y                         1 0 4 8 
 
 # d e f i n e   c k P r e f e t c h                                             1 0 4 9 
 
 # d e f i n e   I c k U s e I S                                                 1 0 5 0 
 
 # d e f i n e   c k U s e I S                                                   1 0 5 1 
 
 # d e f i n e   c k I g n o r e S c h e m a                                     1 0 5 2 
 
 # d e f i n e   t x t D s n N a m e                                             1 0 5 3 
 
 # d e f i n e   t x t D S N D e s c r i p t i o n                               1 0 5 4 
 
 # d e f i n e   c k E n a b l e D y n a m i c C u r s o r                       1 1 0 0 
 
 # d e f i n e   c k D i s a b l e D r i v e r C u r s o r                       1 1 0 1 
 
 # d e f i n e   c k D o n t C a c h e F o r w a r d C u r s o r                 1 1 0 2 
 
 # d e f i n e   c k F o r w a r d C u r s o r O n l y                           1 1 0 3 
 
 # d e f i n e   c k R e t u r n M a t c h e d R o w s                           1 1 0 4 
 
 # d e f i n e   c k E n a b l e S Q L A u t o I s N u l l                       1 1 0 5 
 
 # d e f i n e   c k P a d C h a r F u l l L e n g t h                           1 1 0 6 
 
 # d e f i n e   c k N u l l D a t e                                             1 1 0 7 
 
 # d e f i n e   c k P r e f e t c h R o w s                                     1 1 0 8 
 
 # d e f i n e   c k C o m p r e s s e d                                         1 1 0 9 
 
 # d e f i n e   c k D e b u g                                                   1 1 1 0 
 
 # d e f i n e   c k P r e f e t c h R o w s 2                                   1 1 1 1 
 
 # d e f i n e   c k I g n o r e S p a c e                                       1 1 1 2 
 
 # d e f i n e   c k M u l t i S t m t                                           1 1 1 3 
 
 # d e f i n e   c k M a t c h e d R o w s                                       1 1 1 4 
 
 # d e f i n e   t x t P l u g i n D i r                                         1 1 1 5 
 
 # d e f i n e   p b P l u g i n d i r B r o w s e                               1 1 1 6 
 
 # d e f i n e   t x t S s l K e y                                               1 1 1 7 
 
 # d e f i n e   t x t S s l C e r t                                             1 1 1 8 
 
 # d e f i n e   t x t S s l C e r t A u t h                                     1 1 1 9 
 
 # d e f i n e   t x t S s l C a P a t h                                         1 1 2 0 
 
 # d e f i n e   t x t S s l C i p h e r                                         1 1 2 1 
 
 # d e f i n e   c b S s l V e r i f y                                           1 1 2 2 
 
 # d e f i n e   p b C a P a t h B r o w s e                                     1 1 2 3 
 
 # d e f i n e   p b K e y B r o w s e                                           1 1 2 4 
 
 # d e f i n e   p b C e r t B r o w s e                                         1 1 2 5 
 
 # d e f i n e   p b C a C e r t B r o w s e                                     1 1 2 6 
 
 # d e f i n e   c k U s e M y c n f                                             1 1 2 7 
 
 / *   T L S V E R S I O N   c h e c k b o x   g r o u p .   I d   d e t e r m i n e s   b i t   * / 
 
 # d e f i n e   c b T l s 1 1                                                   1 1 2 8 
 
 # d e f i n e   c b T l s 1 2                                                   1 1 2 9 
 
 # d e f i n e   c b T l s 1 3                                                   1 1 3 1 
 
 / *   E n d   o f   T L S V E R S I O N   * / 
 
 # d e f i n e   c b F o r c e T l s                                             1 3 0 0 
 
 # d e f i n e   t x t S e r v e r K e y                                         1 2 0 0 
 
 # d e f i n e   p b S e r v e r K e y B r o w s e                               1 2 0 1 
 
 # d e f i n e   t x t T l s P e e r F p                                         1 2 1 0 
 
 # d e f i n e   t x t T l s P e e r F p L i s t                                 1 2 1 1 
 
 # d e f i n e   p b F p L i s t B r o w s e                                     1 2 1 2 
 
 # d e f i n e   t x t C r l                                                     1 2 1 3 
 
 # d e f i n e   p b C r l B r o w s e                                           1 2 1 4 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 0 7 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   4 0 0 0 1 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 4 4 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 1 3 
 
 # e n d i f 
 
 # e n d i f 
 
 
